DataSponsorshipUpdatedEffectResponse class

Represents a data entry sponsorship updated effect response from Horizon.

This effect occurs when the sponsor of a data entry's reserve changes.

Triggered by: BeginSponsoringFutureReservesOperation with RevokeSponsorshipOperation Returned by: Horizon API effects endpoint when querying for sponsorship update effects

Example:

final effects = await sdk.effects.forAccount('account_id').execute();
for (var effect in effects.records) {
  if (effect is DataSponsorshipUpdatedEffectResponse) {
    print('Data entry ${effect.dataName} sponsor changed to: ${effect.newSponsor}');
  }
}

See also:

Inheritance

Constructors

DataSponsorshipUpdatedEffectResponse(String dataName, String newSponsor, String formerSponsor, String id, int type_i, String type, String createdAt, String pagingToken, String account, EffectResponseLinks links)
Creates a DataSponsorshipUpdatedEffectResponse from Horizon API effect data.
DataSponsorshipUpdatedEffectResponse.fromJson(Map<String, dynamic> json)
Creates a data sponsorship updated effect from Horizon API JSON response.
factory

Properties

account String
Account ID affected by this effect
getter/setter pairinherited
accountMuxed String?
Muxed account address if the account is a muxed account
getter/setter pairinherited
accountMuxedId String?
Muxed account sub-account ID if applicable
getter/setter pairinherited
createdAt String
When this effect occurred in ISO 8601 format
getter/setter pairinherited
dataName String
The name (key) of the data entry
getter/setter pair
formerSponsor String
The account ID of the former sponsor
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
Unique identifier for this effect
getter/setter pairinherited
Links to related resources
getter/setter pairinherited
newSponsor String
The account ID of the new sponsor
getter/setter pair
pagingToken String
Cursor for pagination
getter/setter pairinherited
rateLimitLimit int?
Maximum number of requests allowed in the current rate limit window.
getter/setter pairinherited
rateLimitRemaining int?
Number of requests remaining in the current rate limit window.
getter/setter pairinherited
rateLimitReset int?
Unix timestamp when the rate limit window will reset.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
Human-readable effect type name
getter/setter pairinherited
type_i int
Effect type as integer code
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setHeaders(Map<String, String> headers) → void
Populates rate limit fields from HTTP response headers.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited