FeeDetails class

Detailed breakdown of fees applied to a transaction.

Provides comprehensive fee information including the total fee amount, the asset in which the fee is charged, and optionally a detailed breakdown of individual fee components that make up the total.

Used within AnchorTransaction to show users exactly what fees were applied to their deposit or withdrawal transaction.

See also:

Constructors

FeeDetails(String total, String asset, {List<FeeDetailsDetails>? details})
Creates fee details with total amount and breakdown for SEP-6 transactions.
FeeDetails.fromJson(Map<String, dynamic> json)
Creates a FeeDetails from JSON returned by the anchor in transaction responses.
factory

Properties

asset String
The asset in which the fee is applied, represented through the Asset Identification Format.
getter/setter pair
details List<FeeDetailsDetails>?
(optional) An array of objects detailing the fees that were used to calculate the conversion price. This can be used to datail the price components for the end-user.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
total String
The total amount of fee applied.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited