signerNotFound constant
int
const signerNotFound
The referenced signer is not present on the context rule.
Implementation
static const int signerNotFound = 3006;
The referenced signer is not present on the context rule.
static const int signerNotFound = 3006;