OZIndexerStatsResponse class

Response from the indexer stats endpoint.

Wraps the indexer's OZIndexerStats payload returned at /api/stats.

Constructors

OZIndexerStatsResponse({required OZIndexerStats stats})
Constructs an indexer stats response.
const
OZIndexerStatsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stats OZIndexerStats
The indexer's aggregate statistics.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override