SEP30ConflictResponseException class
Exception thrown for request conflicts (HTTP 409).
Indicates a conflict with the current state of the resource. Common causes:
- Attempting to register an account that already exists
- Concurrent modifications to account configuration
- Attempting to sign with unverified identity
- Inheritance
-
- Object
- SEP30ResponseException
- SEP30ConflictResponseException
Constructors
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns error message from the recovery service.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited