SEP30Request class

Request for registering or updating account recovery identities.

Contains a list of identities with their authentication methods that will be used for account recovery.

Example:

SEP30AuthMethod email = SEP30AuthMethod("email", "user@example.com");
SEP30RequestIdentity owner = SEP30RequestIdentity("owner", [email]);
SEP30Request request = SEP30Request([owner]);

Constructors

SEP30Request(List<SEP30RequestIdentity> identities)
Creates a SEP30Request with recovery identities.

Properties

hashCode int
The hash code for this object.
no setterinherited
identities List<SEP30RequestIdentity>
List of identities for account recovery.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this SEP-30 request to a JSON map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited