SignerEffectResponse class abstract

Base class for signer-related effect responses from Horizon.

Represents effects that occur when signers are added, removed, or updated on an account.

See also:

Inheritance
Implementers

Constructors

SignerEffectResponse(int weight, String publicKey, String key, String id, int type_i, String type, String createdAt, String pagingToken, String account, EffectResponseLinks links)
Creates a SignerEffectResponse with signer weight, public key and effect details.

Properties

account ↔ String
Account ID affected by this effect
getter/setter pairinherited
accountMuxed ↔ String?
Muxed account address if the account is a muxed account
getter/setter pairinherited
accountMuxedId ↔ String?
Muxed account sub-account ID if applicable
getter/setter pairinherited
createdAt ↔ String
When this effect occurred in ISO 8601 format
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
Unique identifier for this effect
getter/setter pairinherited
key ↔ String
The signer key
getter/setter pair
Links to related resources
getter/setter pairinherited
pagingToken ↔ String
Cursor for pagination
getter/setter pairinherited
publicKey ↔ String
The public key of the signer
getter/setter pair
rateLimitLimit ↔ int?
Maximum number of requests allowed in the current rate limit window.
getter/setter pairinherited
rateLimitRemaining ↔ int?
Number of requests remaining in the current rate limit window.
getter/setter pairinherited
rateLimitReset ↔ int?
Unix timestamp when the rate limit window will reset.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String
Human-readable effect type name
getter/setter pairinherited
type_i ↔ int
Effect type as integer code
getter/setter pairinherited
weight ↔ int
The weight of the signer (0-255)
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setHeaders(Map<String, String> headers) → void
Populates rate limit fields from HTTP response headers.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited