SmartAccountIndexerException class sealed

Indexer-related errors (10xxx range).

Inheritance
Implementers

Properties

cause Object?
The original throwable that triggered this exception, if any.
finalinherited
code SmartAccountErrorCode
The categorised error code for this exception.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
A human-readable error message describing the failure.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

requestFailed(String reason, {Object? cause}) SmartAccountIndexerRequestFailed
Creates an indexer request-failed error using the message format "Indexer request failed: <reason>".
timeout(String url, {Object? cause}) SmartAccountIndexerTimeout
Creates an indexer timeout error using the message format "Indexer request timed out: <url>".