SmartAccountValidationException class sealed

Validation-related errors (7xxx range).

Inheritance
Implementers

Properties

cause → Object?
The original throwable that triggered this exception, if any.
finalinherited
code → SmartAccountErrorCode
The categorised error code for this exception.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
message → String
A human-readable error message describing the failure.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

invalidAddress(String address, {Object? cause}) → SmartAccountInvalidAddress
Creates an invalid-address error using the message format "Invalid address: <address>".
invalidAmount(String amount, {String? reason, Object? cause}) → SmartAccountInvalidAmount
Creates an invalid-amount error using the message format "Invalid amount: <amount>", optionally followed by - <reason> when reason is supplied.
invalidInput(String field, String reason, {Object? cause}) → SmartAccountInvalidInput
Creates an invalid-input error using the message format "Invalid input for <field>: <reason>".