StrictSendPathsRequestBuilder class

Builds requests connected to finding paths. Paths provide information about potential path payments. A path can be used to populate the necessary fields for a path payment operation. The strict receive payment path endpoint lists the paths a payment can take based on the amount of an asset you want to send. The source asset amount stays constant, and the type and amount of an asset received varies based on offers in the order books. See: Stellar developer docs

Inheritance

Constructors

StrictSendPathsRequestBuilder(Client httpClient, Uri serverURI)
Creates a StrictSendPathsRequestBuilder for querying strict send payment paths from Horizon.

Properties

hashCode int
The hash code for this object.
no setterinherited
httpClient ↔ Client
getter/setter pairinherited
queryParameters Map<String, String>
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uriBuilder Uri
getter/setter pairinherited

Methods

buildUri() Uri
Constructs the complete URI for the API request.
inherited
cursor(String cursor) RequestBuilder
Sets the cursor parameter for pagination.
inherited
destinationAccount(String accountId) StrictSendPathsRequestBuilder
Sets the destination account.For this search, Horizon loads a list of assets that the recipient can recieve (based on destination_account or destination_assets) and displays the possible paths from the different source assets to the destination asset. Only paths that satisfy the source_amount are returned. See: Stellar developer docs
destinationAssets(List<Asset> destinationAssets) StrictSendPathsRequestBuilder
Sets the destination assets. For this search, Horizon loads a list of assets that the recipient can recieve (based on destination_account or destination_assets) and displays the possible paths from the different source assets to the destination asset. Only paths that satisfy the source_amount are returned. See: Stellar developer docs
encodeAsset(Asset asset) String
Encodes an asset to its string representation for API requests.
inherited
encodeAssets(List<Asset> assets) String
Encodes a list of assets to comma-separated string for API requests.
inherited
execute() Future<Page<PathResponse>>
Builds and executes the request, returning strict send payment paths.
limit(int number) RequestBuilder
Sets the maximum number of records to return.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
order(RequestBuilderOrder direction) RequestBuilder
Sets the sort order for results.
inherited
setSegments(List<String> segments) RequestBuilder
Sets the URL path segments for this request.
inherited
sourceAmount(String amount) StrictSendPathsRequestBuilder
Sets the source amount. See: Stellar developer docs
sourceAsset(Asset asset) StrictSendPathsRequestBuilder
Sets the source asset. See: Stellar developer docs
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

requestExecute(Client httpClient, Uri uri) Future<Page<PathResponse>>
Executes the HTTP request to fetch strict send payment paths from Horizon. Returns a page of path responses for navigation.