XdrAccountEntryV2 class

Constructors

XdrAccountEntryV2(XdrUint32 _numSponsored, XdrUint32 _numSponsoring, List<XdrAccountID> _signerSponsoringIDs, XdrAccountEntryV2Ext _ext)

Properties

ext XdrAccountEntryV2Ext
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
numSponsored XdrUint32
getter/setter pair
numSponsoring XdrUint32
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signerSponsoringIDs List<XdrAccountID>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBase64EncodedXdrString() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(XdrDataInputStream stream) XdrAccountEntryV2
encode(XdrDataOutputStream stream, XdrAccountEntryV2 encodedAccountEntryV2) → void
fromBase64EncodedXdrString(String base64Encoded) XdrAccountEntryV2