XdrClaimAtom class

Constructors

XdrClaimAtom(XdrClaimAtomType _type)

Properties

discriminant XdrClaimAtomType
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
liquidityPool XdrClaimLiquidityAtom?
getter/setter pair
orderBook XdrClaimOfferAtom?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type XdrClaimAtomType
Alias for discriminant, the original XDR field name.
getter/setter pair
v0 XdrClaimOfferAtomV0?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBase64EncodedXdrString() String
toString() String
A string representation of this object.
inherited
toXdrJson() String
Returns the SEP-0051 XDR-JSON rendering of this value.
toXdrJsonValue() Object?
Returns the SEP-0051 rendering of this XdrClaimAtom.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(XdrDataInputStream stream) XdrClaimAtom
encode(XdrDataOutputStream stream, XdrClaimAtom encodedClaimAtom) → void
fromBase64EncodedXdrString(String base64Encoded) XdrClaimAtom
fromXdrJson(String json) XdrClaimAtom
Parses the SEP-0051 XDR-JSON rendering of a XdrClaimAtom.
fromXdrJsonValue(Object? value) XdrClaimAtom
Reads a XdrClaimAtom from its SEP-0051 rendering.