XdrConfigSettingContractParallelComputeV0 class

Constructors

XdrConfigSettingContractParallelComputeV0(XdrUint32 _ledgerMaxDependentTxClusters)

Properties

hashCode int
The hash code for this object.
no setterinherited
ledgerMaxDependentTxClusters XdrUint32
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBase64EncodedXdrString() String
toString() String
A string representation of this object.
inherited
toXdrJson() String
Returns the SEP-0051 XDR-JSON rendering of this value.
toXdrJsonValue() Object?
Returns the SEP-0051 rendering of this XdrConfigSettingContractParallelComputeV0.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(XdrDataInputStream stream) XdrConfigSettingContractParallelComputeV0
encode(XdrDataOutputStream stream, XdrConfigSettingContractParallelComputeV0 encodedConfigSettingContractParallelComputeV0) → void
fromBase64EncodedXdrString(String base64Encoded) XdrConfigSettingContractParallelComputeV0
fromXdrJson(String json) XdrConfigSettingContractParallelComputeV0
Parses the SEP-0051 XDR-JSON rendering of a XdrConfigSettingContractParallelComputeV0.
fromXdrJsonValue(Object? value) XdrConfigSettingContractParallelComputeV0
Reads a XdrConfigSettingContractParallelComputeV0 from its SEP-0051 rendering.