XdrContractCodeEntry class

Properties

code Uint8List
getter/setter pair
ext XdrContractCodeEntryExt
getter/setter pair
hash XdrHash
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBase64EncodedXdrString() String
toString() String
A string representation of this object.
inherited
toXdrJson() String
Returns the SEP-0051 XDR-JSON rendering of this value.
toXdrJsonValue() Object?
Returns the SEP-0051 rendering of this XdrContractCodeEntry.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(XdrDataInputStream stream) XdrContractCodeEntry
encode(XdrDataOutputStream stream, XdrContractCodeEntry encodedContractCodeEntry) → void
fromBase64EncodedXdrString(String base64Encoded) XdrContractCodeEntry
fromXdrJson(String json) XdrContractCodeEntry
Parses the SEP-0051 XDR-JSON rendering of a XdrContractCodeEntry.
fromXdrJsonValue(Object? value) XdrContractCodeEntry
Reads a XdrContractCodeEntry from its SEP-0051 rendering.