XdrErrorCode class

Constructors

XdrErrorCode(dynamic _value)

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → dynamic
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBase64EncodedXdrString() String
toString() String
A string representation of this object.
override
toXdrJson() String
Returns the SEP-0051 XDR-JSON rendering of this value.
toXdrJsonValue() Object?
Returns this member's SEP-0051 name.

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

decode(XdrDataInputStream stream) XdrErrorCode
encode(XdrDataOutputStream stream, XdrErrorCode value) → void
fromBase64EncodedXdrString(String base64Encoded) XdrErrorCode
fromXdrJson(String json) XdrErrorCode
Parses the SEP-0051 XDR-JSON rendering of a XdrErrorCode.
fromXdrJsonValue(Object? value) XdrErrorCode
Reads a XdrErrorCode from its SEP-0051 name.

Constants

ERR_AUTH → const XdrErrorCode
ERR_CONF → const XdrErrorCode
ERR_DATA → const XdrErrorCode
ERR_LOAD → const XdrErrorCode
ERR_MISC → const XdrErrorCode