XdrExtendFootprintTTLResult class

Properties

code XdrExtendFootprintTTLResultCode
Alias for discriminant, the original XDR field name.
getter/setter pair
discriminant XdrExtendFootprintTTLResultCode
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBase64EncodedXdrString() String
toString() String
A string representation of this object.
inherited
toXdrJson() String
Returns the SEP-0051 XDR-JSON rendering of this value.
toXdrJsonValue() Object?
Returns the SEP-0051 rendering of this XdrExtendFootprintTTLResult.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(XdrDataInputStream stream) XdrExtendFootprintTTLResult
encode(XdrDataOutputStream stream, XdrExtendFootprintTTLResult encodedExtendFootprintTTLResult) → void
fromBase64EncodedXdrString(String base64Encoded) XdrExtendFootprintTTLResult
fromXdrJson(String json) XdrExtendFootprintTTLResult
Parses the SEP-0051 XDR-JSON rendering of a XdrExtendFootprintTTLResult.
fromXdrJsonValue(Object? value) XdrExtendFootprintTTLResult
Reads a XdrExtendFootprintTTLResult from its SEP-0051 rendering.