XdrHotArchiveBucketEntry class

Properties

archivedEntry XdrLedgerEntry?
getter/setter pair
discriminant XdrHotArchiveBucketEntryType
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
key XdrLedgerKey?
getter/setter pair
metaEntry XdrBucketMetadata?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type XdrHotArchiveBucketEntryType
Alias for discriminant, the original XDR field name.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBase64EncodedXdrString() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(XdrDataInputStream stream) XdrHotArchiveBucketEntry
encode(XdrDataOutputStream stream, XdrHotArchiveBucketEntry encodedHotArchiveBucketEntry) → void
fromBase64EncodedXdrString(String base64Encoded) XdrHotArchiveBucketEntry