XdrInt64 class

Constructors

XdrInt64(BigInt _int64)

Properties

hashCode int
The hash code for this object.
no setterinherited
int64 BigInt
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBase64EncodedXdrString() String
toString() String
A string representation of this object.
inherited
toTxRep(String prefix, List<String> lines) → void
toXdrJson() String
Returns the SEP-0051 XDR-JSON rendering of this value.
toXdrJsonValue() Object?
Returns the SEP-0051 rendering of the wrapped value.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(XdrDataInputStream stream) XdrInt64
encode(XdrDataOutputStream stream, XdrInt64 encodedInt64) → void
fromBase64EncodedXdrString(String base64Encoded) XdrInt64
fromTxRep(Map<String, String> map, String prefix) XdrInt64
fromXdrJson(String json) XdrInt64
Parses the SEP-0051 XDR-JSON rendering of a XdrInt64.
fromXdrJsonValue(Object? value) XdrInt64
Reads a XdrInt64 from the SEP-0051 rendering of its value.