XdrLedgerCloseMetaV1 class

Constructors

XdrLedgerCloseMetaV1(XdrLedgerCloseMetaExt _ext, XdrLedgerHeaderHistoryEntry _ledgerHeader, XdrGeneralizedTransactionSet _txSet, List<XdrTransactionResultMeta> _txProcessing, List<XdrUpgradeEntryMeta> _upgradesProcessing, List<XdrSCPHistoryEntry> _scpInfo, XdrUint64 _totalByteSizeOfLiveSorobanState, List<XdrLedgerKey> _evictedKeys, List<XdrLedgerEntry> _unused)

Properties

evictedKeys List<XdrLedgerKey>
getter/setter pair
ext XdrLedgerCloseMetaExt
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
ledgerHeader XdrLedgerHeaderHistoryEntry
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scpInfo List<XdrSCPHistoryEntry>
getter/setter pair
totalByteSizeOfLiveSorobanState XdrUint64
getter/setter pair
txProcessing List<XdrTransactionResultMeta>
getter/setter pair
txSet XdrGeneralizedTransactionSet
getter/setter pair
unused List<XdrLedgerEntry>
getter/setter pair
upgradesProcessing List<XdrUpgradeEntryMeta>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBase64EncodedXdrString() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(XdrDataInputStream stream) XdrLedgerCloseMetaV1
encode(XdrDataOutputStream stream, XdrLedgerCloseMetaV1 encodedLedgerCloseMetaV1) → void
fromBase64EncodedXdrString(String base64Encoded) XdrLedgerCloseMetaV1