XdrSCErrorCode class

Constructors

XdrSCErrorCode(dynamic _value)

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → dynamic
no setter

Methods

enumName() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBase64EncodedXdrString() → String
toString() → String
A string representation of this object.
override
toTxRep(String prefix, List<String> lines) → void
toXdrJson() → String
Returns the SEP-0051 XDR-JSON rendering of this value.
toXdrJsonValue() → Object?
Returns this member's SEP-0051 name.

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

decode(XdrDataInputStream stream) → XdrSCErrorCode
encode(XdrDataOutputStream stream, XdrSCErrorCode value) → void
fromBase64EncodedXdrString(String base64Encoded) → XdrSCErrorCode
fromTxRep(Map<String, String> map, String prefix) → XdrSCErrorCode
fromTxRepName(String name) → XdrSCErrorCode
fromXdrJson(String json) → XdrSCErrorCode
Parses the SEP-0051 XDR-JSON rendering of a XdrSCErrorCode.
fromXdrJsonValue(Object? value) → XdrSCErrorCode
Reads a XdrSCErrorCode from its SEP-0051 name.