XdrSignature class

Constructors

XdrSignature(Uint8List _signature)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signature Uint8List
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBase64EncodedXdrString() String
toString() String
A string representation of this object.
inherited
toTxRep(String prefix, List<String> lines) → void
toXdrJson() String
Returns the SEP-0051 XDR-JSON rendering of this value.
toXdrJsonValue() Object?
Returns the SEP-0051 rendering of the wrapped value.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(XdrDataInputStream stream) XdrSignature
encode(XdrDataOutputStream stream, XdrSignature encodedSignature) → void
fromBase64EncodedXdrString(String base64Encoded) XdrSignature
fromTxRep(Map<String, String> map, String prefix) XdrSignature
fromXdrJson(String json) XdrSignature
Parses the SEP-0051 XDR-JSON rendering of a XdrSignature.
fromXdrJsonValue(Object? value) XdrSignature
Reads a XdrSignature from the SEP-0051 rendering of its value.