XdrTransactionMetaV1 class

Constructors

XdrTransactionMetaV1(XdrLedgerEntryChanges _txChanges, List<XdrOperationMeta> _operations)

Properties

hashCode int
The hash code for this object.
no setterinherited
operations List<XdrOperationMeta>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
txChanges XdrLedgerEntryChanges
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBase64EncodedXdrString() String
toString() String
A string representation of this object.
inherited
toXdrJson() String
Returns the SEP-0051 XDR-JSON rendering of this value.
toXdrJsonValue() Object?
Returns the SEP-0051 rendering of this XdrTransactionMetaV1.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(XdrDataInputStream stream) XdrTransactionMetaV1
encode(XdrDataOutputStream stream, XdrTransactionMetaV1 encodedTransactionMetaV1) → void
fromBase64EncodedXdrString(String base64Encoded) XdrTransactionMetaV1
fromXdrJson(String json) XdrTransactionMetaV1
Parses the SEP-0051 XDR-JSON rendering of a XdrTransactionMetaV1.
fromXdrJsonValue(Object? value) XdrTransactionMetaV1
Reads a XdrTransactionMetaV1 from its SEP-0051 rendering.