XdrTransactionResultResult class

Properties

code XdrTransactionResultCode
Alias for discriminant, the original XDR field name.
getter/setter pair
discriminant XdrTransactionResultCode
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
innerResultPair XdrInnerTransactionResultPair?
getter/setter pair
results List<XdrOperationResult>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBase64EncodedXdrString() String
toString() String
A string representation of this object.
inherited
toXdrJson() String
Returns the SEP-0051 XDR-JSON rendering of this value.
toXdrJsonValue() Object?
Returns the SEP-0051 rendering of this XdrTransactionResultResult.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(XdrDataInputStream stream) XdrTransactionResultResult
encode(XdrDataOutputStream stream, XdrTransactionResultResult encodedTransactionResultResult) → void
fromBase64EncodedXdrString(String base64Encoded) XdrTransactionResultResult
fromXdrJson(String json) XdrTransactionResultResult
Parses the SEP-0051 XDR-JSON rendering of a XdrTransactionResultResult.
fromXdrJsonValue(Object? value) XdrTransactionResultResult
Reads a XdrTransactionResultResult from its SEP-0051 rendering.