XdrValue class

Constructors

XdrValue(Uint8List _value)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value Uint8List
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBase64EncodedXdrString() String
toString() String
A string representation of this object.
inherited
toXdrJson() String
Returns the SEP-0051 XDR-JSON rendering of this value.
toXdrJsonValue() Object?
Returns the SEP-0051 rendering of the wrapped value.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(XdrDataInputStream stream) XdrValue
encode(XdrDataOutputStream stream, XdrValue encodedValue) → void
fromBase64EncodedXdrString(String base64Encoded) XdrValue
fromXdrJson(String json) XdrValue
Parses the SEP-0051 XDR-JSON rendering of a XdrValue.
fromXdrJsonValue(Object? value) XdrValue
Reads a XdrValue from the SEP-0051 rendering of its value.