registerWith static method
Invoked by the generated Flutter web plugin registrant at startup.
Implementation
static void registerWith(Registrar registrar) {}
Invoked by the generated Flutter web plugin registrant at startup.
static void registerWith(Registrar registrar) {}