BumpSequenceOperationBuilder class
Builder for constructing BumpSequence operations.
Provides a fluent interface for building BumpSequence operations with optional parameters. Use this builder to bump account sequence numbers.
Example:
var operation = BumpSequenceOperationBuilder(
BigInt.from(99999)
).setSourceAccount(accountId).build();
Constructors
- BumpSequenceOperationBuilder(BigInt _bumpTo)
- Creates a BumpSequence operation builder.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
) → BumpSequenceOperation - Builds the BumpSequence operation.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setMuxedSourceAccount(
MuxedAccount sourceAccount) → BumpSequenceOperationBuilder - Sets the muxed source account for this operation.
-
setSourceAccount(
String sourceAccountId) → BumpSequenceOperationBuilder - Sets the source account for this operation.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited