OZContractDetailsResponse class
Response containing full details of a smart account contract.
Includes the contract ID, summary information, and all context rules with their signers and policies.
Constructors
-
OZContractDetailsResponse({required String contractId, required OZIndexedContractSummary summary, required List<
OZIndexedContextRule> contextRules}) -
Constructs a contract-details response.
const
-
OZContractDetailsResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
contextRules
→ List<
OZIndexedContextRule> -
All context rules defined for the contract.
final
- contractId → String
-
The contract ID queried.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- summary → OZIndexedContractSummary
-
Summary information about the contract.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override