SmartAccountInvalidAddress class final

The supplied address is not a valid Stellar address.

Inheritance

Constructors

SmartAccountInvalidAddress(String message, [Object? cause])
const

Properties

cause Object?
The original throwable that triggered this exception, if any.
finalinherited
code SmartAccountErrorCode
The categorised error code for this exception.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
A human-readable error message describing the failure.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited