SmartAccountTransactionException class sealed
Transaction-related errors (5xxx range).
- Inheritance
-
- Object
- SmartAccountException
- SmartAccountTransactionException
- Implementers
Properties
- cause → Object?
-
The original throwable that triggered this exception, if any.
finalinherited
- code → SmartAccountErrorCode
-
The categorised error code for this exception.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
A human-readable error message describing the failure.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
signingFailed(
String reason, {Object? cause}) → SmartAccountTransactionSigningFailed -
Creates a transaction-signing-failed error using the message format
"Transaction signing failed: <reason>". -
simulationFailed(
String reason, {Object? cause}) → SmartAccountTransactionSimulationFailed -
Creates a transaction-simulation-failed error using the message format
"Transaction simulation failed: <reason>". -
submissionFailed(
String reason, {Object? cause}) → SmartAccountTransactionSubmissionFailed -
Creates a transaction-submission-failed error using the message format
"Transaction submission failed: <reason>". -
timeout(
{String? details, Object? cause}) → SmartAccountTransactionTimeout -
Creates a transaction-timeout error. When
detailsis omitted the default message"Transaction timed out"is used.