SorobanDelegateDescriptor class
Descriptor for a single delegate node when building a WITH_DELEGATES entry.
Used with SorobanAuthorizationEntry.withDelegates to specify the delegate tree. The signature field defaults to void (the normal pre-signing state). nestedDelegates lists child delegates authorized by this node.
Muxed addresses (M...) are not valid Soroban auth delegate addresses and will be rejected by SorobanAuthorizationEntry.withDelegates.
Constructors
-
SorobanDelegateDescriptor(String addressStrKey, {XdrSCVal? signature, List<
SorobanDelegateDescriptor> nestedDelegates = const []}) -
const
Properties
- addressStrKey → String
-
The strkey of this delegate (G... account or C... contract).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
nestedDelegates
→ List<
SorobanDelegateDescriptor> -
Child delegates authorized by this node (optional; defaults to none).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signature → XdrSCVal?
-
Pre-filled signature for this node. Defaults to void.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited