XdrClaimableBalanceEntryExtV1 class
Constructors
Properties
- ext ↔ XdrClaimableBalanceEntryExtV1Ext
-
getter/setter pair
- flags ↔ XdrUint32
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toBase64EncodedXdrString(
) → String -
toString(
) → String -
A string representation of this object.
inherited
-
toXdrJson(
) → String - Returns the SEP-0051 XDR-JSON rendering of this value.
-
toXdrJsonValue(
) → Object? - Returns the SEP-0051 rendering of this XdrClaimableBalanceEntryExtV1.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
XdrDataInputStream stream) → XdrClaimableBalanceEntryExtV1 -
encode(
XdrDataOutputStream stream, XdrClaimableBalanceEntryExtV1 encodedClaimableBalanceEntryExtV1) → void -
fromBase64EncodedXdrString(
String base64Encoded) → XdrClaimableBalanceEntryExtV1 -
fromXdrJson(
String json) → XdrClaimableBalanceEntryExtV1 - Parses the SEP-0051 XDR-JSON rendering of a XdrClaimableBalanceEntryExtV1.
-
fromXdrJsonValue(
Object? value) → XdrClaimableBalanceEntryExtV1 - Reads a XdrClaimableBalanceEntryExtV1 from its SEP-0051 rendering.