XdrClaimableBalanceEntryExtV1Ext class
Constructors
Properties
- discriminant ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- v ↔ int
-
Alias for discriminant, the original XDR field name.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toBase64EncodedXdrString(
) → String -
toString(
) → String -
A string representation of this object.
inherited
-
toXdrJson(
) → String - Returns the SEP-0051 XDR-JSON rendering of this value.
-
toXdrJsonValue(
) → Object? - Returns the SEP-0051 rendering of this XdrClaimableBalanceEntryExtV1Ext.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
XdrDataInputStream stream) → XdrClaimableBalanceEntryExtV1Ext -
encode(
XdrDataOutputStream stream, XdrClaimableBalanceEntryExtV1Ext encodedClaimableBalanceEntryExtV1Ext) → void -
fromBase64EncodedXdrString(
String base64Encoded) → XdrClaimableBalanceEntryExtV1Ext -
fromXdrJson(
String json) → XdrClaimableBalanceEntryExtV1Ext - Parses the SEP-0051 XDR-JSON rendering of a XdrClaimableBalanceEntryExtV1Ext.
-
fromXdrJsonValue(
Object? value) → XdrClaimableBalanceEntryExtV1Ext - Reads a XdrClaimableBalanceEntryExtV1Ext from its SEP-0051 rendering.