XdrHmacSha256Mac class

Constructors

XdrHmacSha256Mac(Uint8List _mac)

Properties

hashCode int
The hash code for this object.
no setterinherited
mac Uint8List
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBase64EncodedXdrString() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(XdrDataInputStream stream) XdrHmacSha256Mac
encode(XdrDataOutputStream stream, XdrHmacSha256Mac encodedHmacSha256Mac) → void
fromBase64EncodedXdrString(String base64Encoded) XdrHmacSha256Mac