XdrLedgerEntryChange class
Constructors
Properties
- created ↔ XdrLedgerEntry?
-
getter/setter pair
- discriminant ↔ XdrLedgerEntryChangeType
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- removed ↔ XdrLedgerKey?
-
getter/setter pair
- restored ↔ XdrLedgerEntry?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state ↔ XdrLedgerEntry?
-
getter/setter pair
- type ↔ XdrLedgerEntryChangeType
-
Alias for discriminant, the original XDR field name.
getter/setter pair
- updated ↔ XdrLedgerEntry?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toBase64EncodedXdrString(
) → String -
toString(
) → String -
A string representation of this object.
inherited
-
toXdrJson(
) → String - Returns the SEP-0051 XDR-JSON rendering of this value.
-
toXdrJsonValue(
) → Object? - Returns the SEP-0051 rendering of this XdrLedgerEntryChange.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
XdrDataInputStream stream) → XdrLedgerEntryChange -
encode(
XdrDataOutputStream stream, XdrLedgerEntryChange encodedLedgerEntryChange) → void -
fromBase64EncodedXdrString(
String base64Encoded) → XdrLedgerEntryChange -
fromXdrJson(
String json) → XdrLedgerEntryChange - Parses the SEP-0051 XDR-JSON rendering of a XdrLedgerEntryChange.
-
fromXdrJsonValue(
Object? value) → XdrLedgerEntryChange - Reads a XdrLedgerEntryChange from its SEP-0051 rendering.