XdrLedgerKeyContractData class
Constructors
- XdrLedgerKeyContractData(XdrSCAddress _contract, XdrSCVal _key, XdrContractDataDurability _durability)
Properties
- contract ↔ XdrSCAddress
-
getter/setter pair
- durability ↔ XdrContractDataDurability
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- key ↔ XdrSCVal
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toBase64EncodedXdrString(
) → String -
toString(
) → String -
A string representation of this object.
inherited
-
toTxRep(
String prefix, List< String> lines) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
XdrDataInputStream stream) → XdrLedgerKeyContractData -
encode(
XdrDataOutputStream stream, XdrLedgerKeyContractData encodedLedgerKeyContractData) → void -
fromBase64EncodedXdrString(
String base64Encoded) → XdrLedgerKeyContractData -
fromTxRep(
Map< String, String> map, String prefix) → XdrLedgerKeyContractData