XdrLedgerKeyData class
- Inheritance
-
- Object
- XdrLedgerKeyDataBase
- XdrLedgerKeyData
Constructors
- XdrLedgerKeyData(XdrAccountID accountID, XdrString64 dataName)
Properties
- accountID ↔ XdrAccountID
-
getter/setter pairinherited
- dataName ↔ XdrString64
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toBase64EncodedXdrString(
) → String -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toTxRep(
String prefix, List< String> lines) → void -
inherited
-
toXdrJson(
) → String -
Returns the SEP-0051 XDR-JSON rendering of this value.
inherited
-
toXdrJsonValue(
) → Object? -
Returns the SEP-0051 rendering of this XdrLedgerKeyDataBase.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
XdrDataInputStream stream) → XdrLedgerKeyData -
override
-
encode(
XdrDataOutputStream stream, XdrLedgerKeyData val) → void -
override
-
forDataName(
String accountId, String dataName) → XdrLedgerKeyData -
fromTxRep(
Map< String, String> map, String prefix) → XdrLedgerKeyData -
override
-
fromXdrJson(
String json) → XdrLedgerKeyData -
Parses the SEP-0051 XDR-JSON rendering of a XdrLedgerKeyData.
override
-
fromXdrJsonValue(
Object? value) → XdrLedgerKeyData -
Reads a XdrLedgerKeyData from its SEP-0051 rendering.
override