XdrSCAddressBase class
- Implementers
Constructors
- XdrSCAddressBase(XdrSCAddressType _type)
Properties
- accountId ↔ XdrAccountID?
-
getter/setter pair
- claimableBalanceId ↔ XdrClaimableBalanceID?
-
getter/setter pair
- contractId ↔ XdrHash?
-
getter/setter pair
- discriminant ↔ XdrSCAddressType
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- liquidityPoolId ↔ XdrHash?
-
getter/setter pair
- muxedAccount ↔ XdrMuxedAccountMed25519?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ XdrSCAddressType
-
Alias for discriminant, the original XDR field name.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toBase64EncodedXdrString(
) → String -
toString(
) → String -
A string representation of this object.
inherited
-
toTxRep(
String prefix, List< String> lines) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
XdrDataInputStream stream) → XdrSCAddressBase -
decodeAs<
T extends XdrSCAddressBase> (XdrDataInputStream stream, T constructor(XdrSCAddressType)) → T -
encode(
XdrDataOutputStream stream, XdrSCAddressBase encodedSCAddress) → void -
fromBase64EncodedXdrString(
String base64Encoded) → XdrSCAddressBase -
fromTxRep(
Map< String, String> map, String prefix) → XdrSCAddressBase