XdrTransactionEnvelope class
- Inheritance
-
- Object
- XdrTransactionEnvelopeBase
- XdrTransactionEnvelope
Constructors
Properties
- discriminant ↔ XdrEnvelopeType
-
getter/setter pairinherited
- feeBump ↔ XdrFeeBumpTransactionEnvelope?
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ XdrEnvelopeType
-
Alias for discriminant, the original XDR field name.
getter/setter pairinherited
- v0 ↔ XdrTransactionV0Envelope?
-
getter/setter pairinherited
- v1 ↔ XdrTransactionV1Envelope?
-
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toBase64EncodedXdrString(
) → String -
inherited
-
toEnvelopeXdrBase64(
) → String - Legacy name — delegates to toBase64EncodedXdrString.
-
toString(
) → String -
A string representation of this object.
inherited
-
toTxRep(
String prefix, List< String> lines) → void -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
XdrDataInputStream stream) → XdrTransactionEnvelope -
override
-
encode(
XdrDataOutputStream stream, XdrTransactionEnvelope val) → void -
override
-
fromBase64EncodedXdrString(
String base64Encoded) → XdrTransactionEnvelope -
override
-
fromEnvelopeXdrString(
String envelope) → XdrTransactionEnvelope - Legacy name — delegates to fromBase64EncodedXdrString.
-
fromTxRep(
Map< String, String> map, String prefix) → XdrTransactionEnvelope -
override