fromXdrJson static method
Parses the SEP-0051 XDR-JSON rendering of a XdrTransactionEnvelope.
Dart does not inherit statics, so this narrows the base class rendering to this type rather than relying on the one the base declares.
Implementation
static XdrTransactionEnvelope fromXdrJson(String json) => fromXdrJsonValue(
XdrJsonHelper.decodeDocument(json, type: 'XdrTransactionEnvelope'),
);